summaryrefslogtreecommitdiffstats
path: root/policy
diff options
context:
space:
mode:
authorDaniel Sandler <dsandler@android.com>2013-10-14 19:00:10 -0700
committerAndroid Git Automerger <android-git-automerger@android.com>2013-10-14 19:00:10 -0700
commitc963dfb27a160d50b5ed23fd6d296aec0bd0472b (patch)
tree1043e3aa15390e31de6e577029266d085d393c61 /policy
parentc13dd15c5585e829328fc2f1cd7941281ffbcf5c (diff)
parent596b1f86ff1a3457a514e1d383d14ef0defc4d53 (diff)
downloadframeworks_base-c963dfb27a160d50b5ed23fd6d296aec0bd0472b.zip
frameworks_base-c963dfb27a160d50b5ed23fd6d296aec0bd0472b.tar.gz
frameworks_base-c963dfb27a160d50b5ed23fd6d296aec0bd0472b.tar.bz2
am 596b1f86: am dd73ee4d: Add a config resource to enable translucent bars globally.
* commit '596b1f86ff1a3457a514e1d383d14ef0defc4d53': Add a config resource to enable translucent bars globally.
Diffstat (limited to 'policy')
-rw-r--r--policy/src/com/android/internal/policy/impl/PhoneWindowManager.java20
1 files changed, 13 insertions, 7 deletions
diff --git a/policy/src/com/android/internal/policy/impl/PhoneWindowManager.java b/policy/src/com/android/internal/policy/impl/PhoneWindowManager.java
index 5ac3ed0..539d0a0 100644
--- a/policy/src/com/android/internal/policy/impl/PhoneWindowManager.java
+++ b/policy/src/com/android/internal/policy/impl/PhoneWindowManager.java
@@ -297,6 +297,7 @@ public class PhoneWindowManager implements WindowManagerPolicy {
int mCurrentAppOrientation = ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED;
boolean mHasSoftInput = false;
boolean mTouchExplorationEnabled = false;
+ boolean mTranslucentDecorEnabled = true;
int mPointerLocationMode = 0; // guarded by mLock
@@ -901,6 +902,8 @@ public class PhoneWindowManager implements WindowManagerPolicy {
com.android.internal.R.integer.config_lidNavigationAccessibility);
mLidControlsSleep = mContext.getResources().getBoolean(
com.android.internal.R.bool.config_lidControlsSleep);
+ mTranslucentDecorEnabled = mContext.getResources().getBoolean(
+ com.android.internal.R.bool.config_enableTranslucentDecor);
readConfigurationDependentBehaviors();
// register for dock events
@@ -2703,7 +2706,7 @@ public class PhoneWindowManager implements WindowManagerPolicy {
boolean immersiveSticky = (sysui & View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY) != 0;
boolean navAllowedHidden = immersive || immersiveSticky;
navTranslucent &= !immersiveSticky; // transient trumps translucent
- navTranslucent &= isTranslucentNavigationAllowed();
+ navTranslucent &= areTranslucentBarsAllowed();
// When the navigation bar isn't visible, we put up a fake
// input window to catch all touch events. This way we can
@@ -2824,6 +2827,7 @@ public class PhoneWindowManager implements WindowManagerPolicy {
boolean statusBarTransient = (sysui & View.STATUS_BAR_TRANSIENT) != 0;
boolean statusBarTranslucent = (sysui & View.STATUS_BAR_TRANSLUCENT) != 0;
+ statusBarTranslucent &= areTranslucentBarsAllowed();
// If the status bar is hidden, we don't want to cause
// windows behind it to scroll.
@@ -5116,8 +5120,8 @@ public class PhoneWindowManager implements WindowManagerPolicy {
vis = (vis & ~flags) | (oldVis & flags);
}
- if (!isTranslucentNavigationAllowed()) {
- vis &= ~View.NAVIGATION_BAR_TRANSLUCENT;
+ if (!areTranslucentBarsAllowed()) {
+ vis &= ~(View.NAVIGATION_BAR_TRANSLUCENT | View.STATUS_BAR_TRANSLUCENT);
}
// update status bar
@@ -5182,11 +5186,13 @@ public class PhoneWindowManager implements WindowManagerPolicy {
}
/**
* @return whether the navigation bar can be made translucent, e.g. touch
* exploration is not enabled
*/
- private boolean isTranslucentNavigationAllowed() {
- return !mTouchExplorationEnabled;
+ private boolean areTranslucentBarsAllowed() {
+ return mTranslucentDecorEnabled && !mTouchExplorationEnabled;
}
// Use this instead of checking config_showNavigationBar so that it can be consistently
@@ -5182,11 +5186,13 @@ public class PhoneWindowManager implements WindowManagerPolicy {
}
/**
- * @return whether the navigation bar can be made translucent, e.g. touch
- * exploration is not enabled
+ * @return whether the navigation or status bar can be made translucent
+ *
+ * This should return true unless touch exploration is not enabled or
+ * R.boolean.config_enableTranslucentDecor is false.
*/